@@ -3,17 +3,6 @@ from psycopg2 import sql
 from datetime import datetime
 import pytz
 
-def postAccountAddress(connection, schema, data):
-    query = sql.SQL("INSERT INTO {}.dwh_address_account (chain_id,chain,account,public_address,context) VALUES (%s,%s,%s,%s,%s)").format(sql.Identifier(schema))
-    params = (
-        data['chain_id'],
-        data['chain'],
-        data['account'],
-        data['public_address'],
-        data['context'])
-    result = herokuDbAccess.insertDataIntoDatabase(query, params, connection)    
-    return result
-
 def getAccountAddress(connection, schema, account=None, public_address=None, chain=None, chain_id=None):
     conditions = ""
     params = []
@@ -71,8 +60,8 @@ def getUniqueTokenFromTransactions(connection, schema, public_address:str=None,
 
 def getUniqueAddress(connection, schema, chain_id:int=None):
     
-    queryStr = "select distinct(public_address) \
-        FROM {}.dwh_address_account"
+    queryStr = "select distinct(public_address) id, public_address \
+        FROM {}.dwh_public_address"
 
     params = []
 
@@ -104,7 +93,8 @@ def getTxSortedAsc(connection, schema, public_address_list):
     queryStr = "SELECT id, tx_hash, tx_failed, tx_type_no, tx_timestamp, tx_from, \
                         amount_fee_value, amount_fee_value_USD, amount_fee_dwh_token_id,  \
                         amount_send_value, amount_send_value_USD, amount_send_dwh_token_id, \
-                        amount_recv_value, amount_recv_value_USD, amount_recv_dwh_token_id \
+                        amount_recv_value, amount_recv_value_USD, amount_recv_dwh_token_id, \
+                        chain_id, tx_to, created_at, modified_at \
                 FROM {}.dwh_transaction \
                 WHERE public_address IN " + public_address_list + " \
                 ORDER BY tx_timestamp ASC"
@@ -132,6 +122,10 @@ def getTxSortedAsc(connection, schema, public_address_list):
             , 'tx_recv_amount': tx[12]
             , 'tx_recv_amount_usd': tx[13]
             , 'tx_recv_token_id': tx[14]
+            , 'chain_id': tx[15]
+            , 'tx_to': tx[16]
+            , 'created_at': tx[17]
+            , 'modified_at': tx[18]
         }
         retData.append(data.copy())
 
