@@ -111,7 +111,8 @@ def PUT(connection, schema, updates:dict, tableName:str, conditions:dict={}):
 def PUT_BULK(connection, schema, updates:list, tableName:str, conditionColumns:list=['id']):
     '''
     updates must be list of dictionaries (with equal keys!). Key is column name according to database!
-    conditionColumns must be in updates!
+    Every column of the table which is NOT NULL and has no DEFAULT, must occur in updates! Otherwhise an error will occur!
+    keys in conditionColumns must also be in updates!
     '''
     query = sql.SQL('SELECT column_name,data_type FROM information_schema.columns WHERE table_schema = %s AND table_name = %s')
     res = herokuDbAccess.fetchDataInDatabase(query, [schema,tableName], connection)
@@ -271,11 +272,78 @@ def SELECT_FUNCTION(connection, schema,functionName,functionParameter:list,colum
         result.append(resultDict)
     return result
 
+def DELETE(connection, schema, tableName:str, conditions:dict={}):
+
+    query = sql.SQL('SELECT column_name FROM information_schema.columns WHERE table_schema = %s AND table_name = %s')
+    res = herokuDbAccess.fetchDataInDatabase(query, [schema,tableName], connection)
+    columns = []
+    for row in res:
+        columns.append(row[0])
+    
+    sqlTemplateEqual = "{} = %s"
+    sqlTemplateIn = "{} IN ({})"
+    sqlTemplateNotIn = "{} NOT IN ({})"
+    sqlTemplateIsNull = "{} IS NULL"
+    sqlTemplateIsNotNull = "{} IS NOT NULL"
+
+    sqlTemplateLt = "{} < %s"
+    sqlTemplateLte = "{} <= %s"
+    sqlTemplateGt = "{} > %s"
+    sqlTemplateGte = "{} >= %s"
+    conditionArray = []
+    params = []
+    for key in conditions.keys():
+        conditionColumnName = key
+        if type(conditions[key]) == dict:
+            conditionValue = conditions[key]['value']
+            if 'alias' in conditions[key]:
+                conditionColumnName = conditions[key]['alias']
+            sqlTemplate = None
+            if conditions[key]['operator'] == 'lt':
+                sqlTemplate = sqlTemplateLt
+            elif conditions[key]['operator'] == 'lte':
+                sqlTemplate = sqlTemplateLte
+            elif conditions[key]['operator'] == 'gt':
+                sqlTemplate = sqlTemplateGt
+            elif conditions[key]['operator'] == 'gte':
+                sqlTemplate = sqlTemplateGte
+            elif conditions[key]['operator'] == 'not in':
+                sqlTemplate = sqlTemplateNotIn
+            elif conditions[key]['operator'] == 'in':
+                sqlTemplate = sqlTemplateIn
+            elif conditions[key]['operator'] == 'is not':
+                sqlTemplate = sqlTemplateIsNotNull
+        else:
+            conditionValue = conditions[key]
+            if conditionValue is None:
+                sqlTemplate = sqlTemplateIsNull
+            else:
+                sqlTemplate = sqlTemplateEqual
+        
+        
+        if type(conditionValue) == list:
+            if sqlTemplate is None or sqlTemplate not in (sqlTemplateIn,sqlTemplateNotIn):
+                conditionArray.append(sqlTemplateIn.format(conditionColumnName,','.join(['%s'] * len(conditionValue))))
+            else:
+                conditionArray.append(sqlTemplate.format(conditionColumnName,','.join(['%s'] * len(conditionValue))))
+            for item in conditionValue:
+                params.append(item) 
+        else:
+            conditionArray.append(sqlTemplate.format(conditionColumnName))
+            if conditionValue is not None:
+                params.append(conditionValue) 
+   
+    queryString = "DELETE FROM {{}}.{} WHERE 1=1 AND {}".format(tableName,' AND '.join(conditionArray))
+    query = sql.SQL(queryString).format(sql.Identifier(schema))
+    res = herokuDbAccess.insertDataIntoDatabase(query, params, connection)    
+
+    return True
+
 # import os
 # from dotenv import load_dotenv
 # import herokuDbAccess as db
 # import time
-# import decimal
+# from decimal import Decimal
 
 # load_dotenv()
 
@@ -306,12 +374,22 @@ def SELECT_FUNCTION(connection, schema,functionName,functionParameter:list,colum
 
 # if __name__ == '__main__':
 #     connection = db.connect(
-#         os.environ.get("HEROKU_GOD_USER"),
-#         os.environ.get("HEROKU_GOD_PASSWORD"),
+#         os.environ.get("HEROKU_USER"),
+#         os.environ.get("HEROKU_PASSWORD"),
 #         os.environ.get("HEROKU_HOST"),
 #         os.environ.get("HEROKU_PORT"),
 #         os.environ.get("HEROKU_DB")
 #     )
+
+#     dataList = []
+#     data = {
+#         'id': '1' 
+#         , 'amount_fee_value_usd': Decimal(1)
+#         , 'amount_send_value_usd': Decimal(1)
+#         , 'amount_recv_value_usd': Decimal(1)
+#     }
+#     dataList.append(data)
+#     PUT_BULK(connection, 'dbdev', dataList, "dwh_transaction", ['id'])
 #     conditions = {
 #         'transaction_type': {
 #             'operator': 'not in',
@@ -330,8 +408,12 @@ def SELECT_FUNCTION(connection, schema,functionName,functionParameter:list,colum
 #         }
 
 #     }
-#     #conditions = {'transaction_type': "auth"}
-#     SELECT(connection,os.environ.get("ENVIRONMENT"),[],'dfi_blockchain_data',conditions)
+    # conditions = {'num': {
+    #          'operator': 'gte',
+    #          'value': 2
+    #      }
+    # }
+    # DELETE(connection,'dbdev','del_test',conditions)
 
 #     r = POST_BULK(connection,'dbdev','testbulk',[{'number':2}],True)
 #     print(r)
